@@ -8,7 +8,7 @@ from persiststate import PersistentState
 
 from pairtree import PairtreeStorageClient
 from pairtree import id_encode, id_decode
-from pairtree import FileNotFoundException
+from pairtree import FileNotFoundException, ObjectNotFoundException
 
 from datetime import datetime
 
@@ -411,7 +411,12 @@ class Silo(object):
             return HarvestedRecord(p_obj, date)
 
     def del_item(self, item_id):
-        return self._store.delete_object(item_id)
+        if self.exists(item_id):
+            return self._store.delete_object(item_id)
+        elif self.exists(self.state['uri_base'] + item_id):
+            return self._store.delete_object(self.state['uri_base'] + item_id)
+        else:
+            raise ObjectNotFoundException
 
     def list_items(self):
         return self._store.list_ids()
